@@ -12,9 +12,13 @@
 /* Version macros for LibJWT */
 #define JWT_VERSION_MAJOR	3
 #define JWT_VERSION_MINOR	2
-#define JWT_VERSION_MICRO	1
+#define JWT_VERSION_MICRO	2
 
-#define JWT_VERSION_STRING	"3.2.1"
+#define JWT_VERSION_STRING	"3.2.2"
+
+/* Whether the system supports "long long". This is primarily to sync
+ * with jansson's json_int_t when working with JSON integers. */
+#define JWT_USES_LONG_LONG	1
 
 #ifdef JWT_STATIC_DEFINE
 #  define JWT_EXPORT
